@@ -18,7 +18,7 @@ describe 'PuppetSyntax rake tasks' do
   it 'should generate FileList of manifests relative to Rakefile' do
     list = PuppetSyntax::RakeTask.new.filelist_manifests
     expect(list).to include(known_pp)
-    expect(list.count).to eq 8
+    expect(list.count).to eq 9
   end
 
   it 'should generate FileList of templates relative to Rakefile' do
@@ -35,21 +35,4 @@ describe 'PuppetSyntax rake tasks' do
     expect(list).to include(known_eyaml_subdir)
     expect(list.count).to eq 4
   end
-
-  it 'should check manifests relative to Rakefile' do
-    if RSpec::Version::STRING < '3'
-      pending
-    else
-      skip('needs to be done')
-    end
-  end
-
-  it 'should check templates relative to Rakefile' do
-    if RSpec::Version::STRING < '3'
-      pending
-    else
-      skip('needs to be done')
-    end
-  end
-
 end
